==> haskell-hashable-time-0.2.0.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable-time
version:              0.2.0.2
visibility:           public
id:                   hashable-time-0.2.0.2-CFwCVOj5JQJJ1PZR1vwuH8
key:                  hashable-time-0.2.0.2-CFwCVOj5JQJJ1PZR1vwuH8
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  ae85f5bbd1d6182b8553f624fd102579
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-8.8.3/site-local/hashable-time-0.2.0.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hashable-time-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/hashable-time-0.2.0.2
hs-libraries:         HShashable-time-0.2.0.2-CFwCVOj5JQJJ1PZR1vwuH8
depends:
    base-4.13.0.0 hashable-1.3.0.0-GFyEr4gS8CZEgl3N6WrORB time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-time-0.2.0.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable-time
version:              0.2.0.2
visibility:           public
id:                   hashable-time-0.2.0.2-Ct4KayE6OIvJQu2VMNPjcC
key:                  hashable-time-0.2.0.2-Ct4KayE6OIvJQu2VMNPjcC
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  484bb2c0e54b9db7c3075ddb32a3848c
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hashable-time-0.2.0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hashable-time-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hashable-time-0.2.0.2
hs-libraries:         HShashable-time-0.2.0.2-Ct4KayE6OIvJQu2VMNPjcC
depends:
    base-4.14.0.0 hashable-1.3.0.0-1Vf2Ag4BrTJ2HvpfsDNoTB time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
